@@ -1,14 +1,10 @@
 """Collect information about dependencies between a github repo and other repositories. Results available in JSON, markdown and badges."""
 
 import sys
+from importlib import metadata as importlib_metadata
 
 from .gh_dependents_info import GithubDependentsInfo
 
-if sys.version_info >= (3, 8):
-    from importlib import metadata as importlib_metadata
-else:
-    import importlib_metadata
-
 
 def get_version() -> str:
     try:
